==> ant-design-vue-3.2.20.jar: META-INF/resources/webjars/ant-design-vue/3.2.20/es/list/Item.d.ts <==
import type { CSSProperties, ExtractPropTypes, PropType } from 'vue';
import type { ListGridType } from '.';
export declare const listItemProps: () => {
    prefixCls: StringConstructor;
    extra: import("vue-types").VueTypeValidableDef<any>;
    actions: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    grid: PropType<ListGridType>;
    colStyle: {
        type: PropType<CSSProperties>;
        default: CSSProperties;
    };
};
export declare type ListItemProps = Partial<ExtractPropTypes<ReturnType<typeof listItemProps>>>;
declare const _default: import("vue").DefineComponent<{
    prefixCls: StringConstructor;
    extra: import("vue-types").VueTypeValidableDef<any>;
    actions: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    grid: PropType<ListGridType>;
    colStyle: {
        type: PropType<CSSProperties>;
        default: CSSProperties;
    };
}, () => JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<ExtractPropTypes<{
    prefixCls: StringConstructor;
    extra: import("vue-types").VueTypeValidableDef<any>;
    actions: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    grid: PropType<ListGridType>;
    colStyle: {
        type: PropType<CSSProperties>;
        default: CSSProperties;
    };
}>>, {
    actions: unknown[];
    colStyle: CSSProperties;
}>;
export default _default;

==> ant-design-vue-4.2.6.jar: META-INF/resources/webjars/ant-design-vue/4.2.6/es/list/Item.d.ts <==
import type { CSSProperties, ExtractPropTypes, PropType } from 'vue';
import type { ListGridType } from '.';
import type { CustomSlotsType } from '../_util/type';
export declare const listItemProps: () => {
    prefixCls: StringConstructor;
    extra: import("vue-types").VueTypeValidableDef<any>;
    actions: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    grid: PropType<ListGridType>;
    colStyle: {
        type: PropType<CSSProperties>;
        default: CSSProperties;
    };
};
export type ListItemProps = Partial<ExtractPropTypes<ReturnType<typeof listItemProps>>>;
declare const _default: import("vue").DefineComponent<ExtractPropTypes<{
    prefixCls: StringConstructor;
    extra: import("vue-types").VueTypeValidableDef<any>;
    actions: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    grid: PropType<ListGridType>;
    colStyle: {
        type: PropType<CSSProperties>;
        default: CSSProperties;
    };
}>, () => import("vue/jsx-runtime").JSX.Element, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<ExtractPropTypes<{
    prefixCls: StringConstructor;
    extra: import("vue-types").VueTypeValidableDef<any>;
    actions: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    grid: PropType<ListGridType>;
    colStyle: {
        type: PropType<CSSProperties>;
        default: CSSProperties;
    };
}>> & Readonly<{}>, {
    actions: unknown[];
    colStyle: CSSProperties;
}, CustomSlotsType<{
    actions: any;
    extra: any;
    default: any;
}>, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export default _default;
